@@ -14,8 +14,9 @@ synchronous or asynchronous contexts via asyncio.
 
     cape = Cape()
 
-    f = FunctionRef.from_json("function.json")
-    cape.connect(f)
+    f = cape.function("user/pythagorean")  # refer to function by name
+    t = cape.token("user.token")           # load function owner's PAT
+    cape.connect(f, t)
 
     c1 = cape.invoke(3, 4, use_serdio=True)
     print(c1)  # 5
@@ -27,7 +28,7 @@ synchronous or asynchronous contexts via asyncio.
 
     # similar invocation, but async
     c3 = asyncio.run(
-        cape.run("9712r5dynf57l1rcns2", 8, 15, use_serdio=True)
+        cape.run(f, t, 8, 15, use_serdio=True)
     )
     print(c3)  # 17
 
@@ -564,10 +565,7 @@ class Cape:
                 f"Bad response from '/v1/user/{username}/key' route, expected "
                 f"attestation_document key-value: {response}."
             )
-        root_cert = self._root_cert or attest.download_root_cert()
-        attestation_doc = attest.parse_attestation(
-            base64.b64decode(adoc_blob), root_cert
-        )
+        attestation_doc = attest.parse_attestation(base64.b64decode(adoc_blob), None)
         if pcrs is not None:
             attest.verify_pcrs(pcrs, attestation_doc)
 
